@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-combinators
 version: 1.0.3.1
-id: conduit-combinators-1.0.3.1-1a8f798e0e5afa4c3be6aadf393ed2f9
-key: condu_GdjNJ2E2jgTBakfnJEwCLC
+id: conduit-combinators-1.0.3.1-5510160cdd233fedb811dec766e2faa2
+key: condu_LGZ8lT8iD8M3LQ5ikr0iRO
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/conduit-combinators
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
-hs-libraries: HSconduit-combinators-1.0.3.1-GdjNJ2E2jgTBakfnJEwCLC
+hs-libraries: HSconduit-combinators-1.0.3.1-LGZ8lT8iD8M3LQ5ikr0iRO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
@@ -29,7 +29,7 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     chunked-data-0.2.0-58ae738dfc85ce16f60338cfe67845f2
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
